function [ H ] = DrawFrames( AA,P,F,c )
%AA-hipermatriz com as transforma��es geom�tricas
%P-objeto
%F-faces do objeto
%H-vetor de handles gr�ficos para todos os sistemas de coordenadas
%desenhados num cell array
%M-vetor de cores
h1=patch('Vertices',P(1:3,:)','Faces',F,'FaceColor','w'); %%desenha origem
H{1}=h1;
A=eye(4);
for n=1:size(AA,3)
   A=A*AA(:,:,n);
   Q=A*P;
   if nargin ==4
        color = c(n);
    else
        color = 'y';
    end
   h1=patch('Vertices',Q(1:3,:)','Faces',F,'FaceColor',color); %desenha sistemas de coordenadas em cada ponto
   H{n+1}=h1;
end


end

